@@ -44,7 +44,6 @@ describe 'trove::keystone::authtoken' do
         is_expected.to contain_trove_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_config('keystone_authtoken/region_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_config('keystone_authtoken/revocation_cache_time').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_config('keystone_authtoken/signing_dir').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_config('keystone_authtoken/token_cache_time').with_value('<SERVICE DEFAULT>')
       end
     end
@@ -86,7 +85,6 @@ describe 'trove::keystone::authtoken' do
           :manage_memcache_package              => true,
           :region_name                          => 'region2',
           :revocation_cache_time                => '11',
-          :signing_dir                          => '/var/cache',
           :token_cache_time                     => '301',
         })
       end
@@ -125,7 +123,6 @@ describe 'trove::keystone::authtoken' do
         is_expected.to contain_trove_config('keystone_authtoken/memcached_servers').with_value('memcached01:11211,memcached02:11211')
         is_expected.to contain_trove_config('keystone_authtoken/region_name').with_value(params[:region_name])
         is_expected.to contain_trove_config('keystone_authtoken/revocation_cache_time').with_value(params[:revocation_cache_time])
-        is_expected.to contain_trove_config('keystone_authtoken/signing_dir').with_value(params[:signing_dir])
         is_expected.to contain_trove_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
       end
 
